@@ -5,13 +5,10 @@ import os
 import pathlib
 import subprocess
 import tempfile
+import warnings
 
-import anndata2ri
 import numpy as np
 import pandas as pd
-import rpy2.rinterface_lib.callbacks
-import rpy2.rinterface_lib.embedded
-import rpy2.robjects as ro
 import scanpy as sc
 import scipy.sparse
 from deprecated import deprecated
@@ -19,15 +16,11 @@ from scipy.io import mmwrite
 
 import scib
 
-from ..exceptions import RLibraryNotFound
+from ..exceptions import OptionalDependencyNotInstalled, RLibraryNotFound
 from ..utils import check_adata, check_batch
 
-rpy2.rinterface_lib.callbacks.logger.setLevel(
-    logging.ERROR
-)  # Ignore R warning messages
 
-
-# Graph LISI (analoguous to lisi function)
+# Graph LISI (analogous to lisi function)
 def lisi_graph(adata, batch_key, label_key, **kwargs):
     """cLISI and iLISI scores
 
@@ -43,15 +36,16 @@ def lisi_graph(adata, batch_key, label_key, **kwargs):
     :return: Overall cLISI and iLISI scores
     """
     ilisi = ilisi_graph(adata, batch_key=batch_key, **kwargs)
-    clisi = clisi_graph(adata, batch_key=batch_key, label_key=label_key, **kwargs)
+    clisi = clisi_graph(adata, label_key=label_key, **kwargs)
     return ilisi, clisi
 
 
 def ilisi_graph(
     adata,
     batch_key,
+    type_,
+    use_rep="X_emb",
     k0=90,
-    type_=None,
     subsample=None,
     scale=True,
     n_cores=1,
@@ -59,32 +53,53 @@ def ilisi_graph(
 ):
     """Integration LISI (iLISI) score
 
-    Local Inverse Simpson’s Index metrics adapted from https://doi.org/10.1038/s41592-019-0619-0 to run on all full
+    Local Inverse Simpson’s Index metrics adapted from `Korsunsky et al. 2019`_ to run on all full
     feature, embedding and kNN integration outputs via shortest path-based distance computation on single-cell kNN
     graphs.
     By default, this function returns a value scaled between 0 and 1 instead of the original LISI range of 0 to the
     number of batches.
 
+    .. _Korsunsky et al. 2019: https://doi.org/10.1038/s41592-019-0619-0
+
     :param adata: adata object to calculate on
     :param batch_key: batch column name in ``adata.obs``
+    :param `type_`: type of data integration, one of 'knn', 'embed' or 'full'
+    :param use_rep: embedding slot in ``.obsm``, only used for embedding input
     :param k0: number of nearest neighbors to compute lisi score
         Please note that the initial neighborhood size that is
         used to compute shortest paths is 15.
-    :param `type_`: type of data integration, either knn, full or embed
     :param subsample: Percentage of observations (integer between 0 and 100)
         to which lisi scoring should be subsampled
     :param scale: scale output values between 0 and 1 (True/False)
     :param n_cores: number of cores (i.e. CPUs or CPU cores to use for multiprocessing)
     :return: Median of iLISI scores per batch labels
+
+    This function can be applied to all integration output types and recomputes the kNN graph for feature and embedding
+    output with specific parameters.
+    Thus, no preprocessing is required, but the correct output type must be specified in ``type_``.
+
+    **Examples**
+
+    .. code-block:: python
+
+        # feature output or unintegrated object
+        scib.me.ilisi_graph(adata, batch_key="batch", type="full")
+
+        # embeding output
+        scib.me.ilisi_graph(adata, batch_key="batch", type="embed", use_rep="X_emb")
+
+        # knn output
+        scib.me.ilisi_graph(adata, batch_key="batch", type="knn")
+
     """
 
     check_adata(adata)
     check_batch(batch_key, adata.obs)
 
-    adata_tmp = recompute_knn(adata, type_)
+    adata_tmp = recompute_knn(adata, type_, use_rep)
     ilisi_score = lisi_graph_py(
         adata=adata_tmp,
-        batch_key=batch_key,
+        obs_key=batch_key,
         n_neighbors=k0,
         perplexity=None,
         subsample=subsample,
@@ -104,10 +119,11 @@ def ilisi_graph(
 
 def clisi_graph(
     adata,
-    batch_key,  # TODO: remove
     label_key,
+    type_,
+    use_rep="X_emb",
+    batch_key=None,
     k0=90,
-    type_=None,
     subsample=None,
     scale=True,
     n_cores=1,
@@ -115,35 +131,57 @@ def clisi_graph(
 ):
     """Cell-type LISI (cLISI) score
 
-    Local Inverse Simpson’s Index metrics adapted from https://doi.org/10.1038/s41592-019-0619-0 to run on all full
+    Local Inverse Simpson’s Index metrics adapted from `Korsunsky et al. 2019`_ to run on all full
     feature, embedding and kNN integration outputs via shortest path-based distance computation on single-cell kNN
     graphs.
     By default, this function returns a value scaled between 0 and 1 instead of the original LISI range of 0 to the
     number of labels.
 
+    .. _Korsunsky et al. 2019: https://doi.org/10.1038/s41592-019-0619-0
+
     :param adata: adata object to calculate on
-    :param batch_key: batch column name in ``adata.obs``
     :param label_key: label column name in ``adata.obs``
+    :param `type_`: type of data integration, one of 'knn', 'embed' or 'full'
+    :param use_rep: embedding slot in ``.obsm``, only used for embedding input
+    :param batch_key: deprecated, not used
     :param k0: number of nearest neighbors to compute lisi score
         Please note that the initial neighborhood size that is
         used to compute shortest paths is 15.
-    :param `type_`: type of data integration, either knn, full or embed
     :param subsample: Percentage of observations (integer between 0 and 100)
         to which lisi scoring should be subsampled
     :param scale: scale output values between 0 and 1 (True/False)
     :param n_cores: number of cores (i.e. CPUs or CPU cores to use for multiprocessing)
     :return: Median of cLISI scores per cell type labels
+
+    This function can be applied to all integration output types and recomputes the kNN graph for feature and embedding
+    output with specific parameters.
+    Thus, no preprocessing is required, but the correct output type must be specified in ``type_``.
+
+    **Examples**
+
+    .. code-block:: python
+
+        # feature output or unintegrated object
+        scib.me.clisi_graph(adata, label_key="celltype", type="full")
+
+        # embeding output
+        scib.me.clisi_graph(adata, label_key="celltype", type="embed", use_rep="X_emb")
+
+        # knn output
+        scib.me.clisi_graph(adata, label_key="celltype", type="knn")
+
     """
+    if batch_key is not None:
+        warnings.warn("'batch_key' is deprecated and will be ignore")
 
     check_adata(adata)
-    check_batch(batch_key, adata.obs)  # TODO: remove
     check_batch(label_key, adata.obs)
 
-    adata_tmp = recompute_knn(adata, type_)
+    adata_tmp = recompute_knn(adata, type_, use_rep)
 
     scores = lisi_graph_py(
         adata=adata_tmp,
-        batch_key=label_key,
+        obs_key=label_key,
         n_neighbors=k0,
         perplexity=None,
         subsample=subsample,
@@ -161,10 +199,10 @@ def clisi_graph(
     return clisi
 
 
-def recompute_knn(adata, type_):
+def recompute_knn(adata, type_, use_rep="X_emb"):
     """Recompute neighbours"""
     if type_ == "embed":
-        return sc.pp.neighbors(adata, n_neighbors=15, use_rep="X_emb", copy=True)
+        return sc.pp.neighbors(adata, n_neighbors=15, use_rep=use_rep, copy=True)
     elif type_ == "full":
         if "X_pca" not in adata.obsm.keys():
             sc.pp.pca(adata, svd_solver="arpack")
@@ -176,7 +214,7 @@ def recompute_knn(adata, type_):
 
 def lisi_graph_py(
     adata,
-    batch_key,
+    obs_key,
     n_neighbors=90,
     perplexity=None,
     subsample=None,
@@ -188,7 +226,6 @@ def lisi_graph_py(
     Compute LISI score on shortes path based on kNN graph provided in the adata object.
     By default, perplexity is chosen as 1/3 * number of nearest neighbours in the knn-graph.
     """
-
     # use no more than the available cores
     n_cores = max(1, min(n_cores, mp.cpu_count()))
 
@@ -203,8 +240,8 @@ def lisi_graph_py(
     if verbose:
         print("Convert nearest neighbor matrix and distances for LISI.")
 
-    batch = adata.obs[batch_key].cat.codes.values
-    n_batches = len(np.unique(adata.obs[batch_key]))
+    batch = adata.obs[obs_key].cat.codes.values
+    n_batches = len(np.unique(adata.obs[obs_key]))
 
     if perplexity is None or perplexity >= n_neighbors:
         # use LISI default
@@ -259,7 +296,7 @@ def lisi_graph_py(
         print(f'call {" ".join(args_int)}')
     try:
         subprocess.run(args_int)
-    except rpy2.rinterface_lib.embedded.RRuntimeError as ex:
+    except RuntimeError as ex:
         print(f"Error computing LISI kNN graph {ex}\nSetting value to np.nan")
         return np.nan
 
@@ -689,6 +726,15 @@ def lisi_knn(adata, batch_key, label_key, perplexity=None, verbose=False):
     Compute LISI score on kNN graph provided in the adata object. By default, perplexity
     is chosen as 1/3 * number of nearest neighbours in the knn-graph.
     """
+    try:
+        import anndata2ri
+        import rpy2.rinterface_lib.callbacks
+        import rpy2.rinterface_lib.embedded
+        import rpy2.robjects as ro
+
+        rpy2.rinterface_lib.callbacks.logger.setLevel(logging.ERROR)
+    except ModuleNotFoundError as e:
+        raise OptionalDependencyNotInstalled(e)
 
     if "neighbors" not in adata.uns:
         raise AttributeError(
@@ -788,6 +834,15 @@ def lisi_matrix(adata, batch_key, label_key, matrix=None, verbose=False):
     LISI R package is called with default parameters. This function takes a data matrix and
     recomputes nearest neighbours.
     """
+    try:
+        import anndata2ri
+        import rpy2.rinterface_lib.callbacks
+        import rpy2.rinterface_lib.embedded
+        import rpy2.robjects as ro
+
+        rpy2.rinterface_lib.callbacks.logger.setLevel(logging.ERROR)
+    except ModuleNotFoundError as e:
+        raise OptionalDependencyNotInstalled(e)
 
     if matrix is None:
         matrix = adata.X
