@@ -1,8 +1,11 @@
+import numpy as np
 import pandas as pd
+from scanpy._utils import deprecated_arg_names
 from sklearn.metrics.cluster import silhouette_samples, silhouette_score
 
 
-def silhouette(adata, group_key, embed, metric="euclidean", scale=True):
+@deprecated_arg_names({"group_key": "label_key"})
+def silhouette(adata, label_key, embed, metric="euclidean", scale=True):
     """Average silhouette width (ASW)
 
     Wrapper for sklearn silhouette function values range from [-1, 1] with
@@ -13,25 +16,45 @@ def silhouette(adata, group_key, embed, metric="euclidean", scale=True):
 
     By default, the score is scaled between 0 and 1 (``scale=True``).
 
-    :param group_key: key in adata.obs of cell labels
+    :param label_key: key in adata.obs of cell labels
     :param embed: embedding key in adata.obsm, default: 'X_pca'
+    :param metric: type of distance metric to use for the silhouette scores
     :param scale: default True, scale between 0 (worst) and 1 (best)
+
+    The function requires an embedding to be stored in ``adata.obsm`` and can only be applied to feature and embedding
+    integration outputs.
+    Please note, that the metric cannot be used to evaluate kNN graph outputs.
+    See :ref:`preprocessing` for more information on preprocessing.
+
+    **Examples**
+
+    .. code-block:: python
+
+        # full feature output
+        scib.pp.reduce_data(
+            adata, n_top_genes=2000, batch_key="batch", pca=True, neighbors=False
+        )
+        scib.me.silhouette(adata, label_key="celltype", embed="X_pca")
+
+        # embedding output
+        scib.me.silhouette(adata, label_key="celltype", embed="X_emb")
     """
     if embed not in adata.obsm.keys():
         print(adata.obsm.keys())
         raise KeyError(f"{embed} not in obsm")
     asw = silhouette_score(
-        X=adata.obsm[embed], labels=adata.obs[group_key], metric=metric
+        X=adata.obsm[embed], labels=adata.obs[label_key], metric=metric
     )
     if scale:
         asw = (asw + 1) / 2
     return asw
 
 
+@deprecated_arg_names({"group_key": "label_key"})
 def silhouette_batch(
     adata,
     batch_key,
-    group_key,
+    label_key,
     embed,
     metric="euclidean",
     return_all=False,
@@ -64,9 +87,8 @@ def silhouette_batch(
 
         batch \\, ASW_j = \\frac{1}{|C_j|} \\sum_{i \\in C_j} 1 - |silhouette(i)|
 
-
     :param batch_key: batch labels to be compared against
-    :param group_key: group labels to be subset by e.g. cell type
+    :param label_key: group labels to be subset by e.g. cell type
     :param embed: name of column in adata.obsm
     :param metric: see sklearn silhouette score
     :param scale: if True, scale between 0 and 1
@@ -77,42 +99,61 @@ def silhouette_batch(
         Batch ASW  (always)
         Mean silhouette per group in pd.DataFrame (additionally, if return_all=True)
         Absolute silhouette scores per group label (additionally, if return_all=True)
+
+    The function requires an embedding to be stored in ``adata.obsm`` and can only be applied to feature and embedding
+    integration outputs.
+    Please note, that the metric cannot be used to evaluate kNN graph outputs.
+    See :ref:`preprocessing` for more information on preprocessing.
+
+    **Examples**
+
+    .. code-block:: python
+
+        # feature output
+        scib.pp.reduce_data(
+            adata, n_top_genes=2000, batch_key="batch", pca=True, neighbors=False
+        )
+        scib.me.silhouette_batch(adata, batch_key="batch", label_key="celltype", embed="X_pca")
+
+        # embedding output
+        scib.me.silhouette_batch(adata, batch_key="batch", label_key="celltype", embed="X_emb")
+
     """
     if embed not in adata.obsm.keys():
         print(adata.obsm.keys())
         raise KeyError(f"{embed} not in obsm")
 
-    sil_dfs = []
-    for group in adata.obs[group_key].unique():
-        adata_group = adata[adata.obs[group_key] == group]
+    sil_per_label = []
+    for group in adata.obs[label_key].unique():
+        adata_group = adata[adata.obs[label_key] == group]
         n_batches = adata_group.obs[batch_key].nunique()
 
         if (n_batches == 1) or (n_batches == adata_group.shape[0]):
             continue
 
-        sil_per_group = silhouette_samples(
+        sil = silhouette_samples(
             adata_group.obsm[embed], adata_group.obs[batch_key], metric=metric
         )
 
         # take only absolute value
-        sil_per_group = [abs(i) for i in sil_per_group]
+        sil = [abs(i) for i in sil]
 
         if scale:
             # scale s.t. highest number is optimal
-            sil_per_group = [1 - i for i in sil_per_group]
+            sil = [1 - i for i in sil]
 
-        sil_dfs.append(
-            pd.DataFrame(
-                {
-                    "group": [group] * len(sil_per_group),
-                    "silhouette_score": sil_per_group,
-                }
-            )
-        )
+        sil_per_label.extend([(group, score) for score in sil])
 
-    sil_df = pd.concat(sil_dfs).reset_index(drop=True)
-    sil_means = sil_df.groupby("group").mean()
-    asw = sil_means["silhouette_score"].mean()
+    sil_df = pd.DataFrame.from_records(
+        sil_per_label, columns=["group", "silhouette_score"]
+    )
+
+    if len(sil_per_label) == 0:
+        sil_means = np.nan
+        asw = np.nan
+    else:
+        sil_means = sil_df.groupby("group").mean()
+        asw = sil_means["silhouette_score"].mean()
 
     if verbose:
         print(f"mean silhouette per group: {sil_means}")
