@@ -1,11 +1,9 @@
 import logging
+import re
 import tempfile
 
-import anndata2ri
 import numpy as np
-import rpy2.rinterface_lib.callbacks  # rpy2 for running R code
-import rpy2.rinterface_lib.embedded
-import rpy2.robjects as ro
+import pandas as pd
 import scanpy as sc
 import seaborn
 import seaborn as sns
@@ -13,10 +11,8 @@ from matplotlib import pyplot as plt
 from scipy import sparse
 
 from . import utils  # TODO: move util fcns (eg reader) elsewhere
-from .exceptions import RLibraryNotFound
+from .exceptions import OptionalDependencyNotInstalled, RLibraryNotFound
 
-# Ignore R warning messages
-rpy2.rinterface_lib.callbacks.logger.setLevel(logging.ERROR)
 seaborn.set_context("talk")
 
 
@@ -243,6 +239,16 @@ def normalize(
     :param min_mean: parameter of ``scran``'s ``computeSumFactors`` function
     :param log: whether to performing log1p-transformation after normalisation
     """
+    try:
+        import anndata2ri
+        import rpy2.rinterface_lib.callbacks
+        import rpy2.rinterface_lib.embedded
+        import rpy2.robjects as ro
+
+        rpy2.rinterface_lib.callbacks.logger.setLevel(logging.ERROR)
+    except ModuleNotFoundError as e:
+        raise OptionalDependencyNotInstalled(e)
+
     utils.check_adata(adata)
 
     # Check for 0 count cells
@@ -562,7 +568,7 @@ def reduce_data(
     overwrite_hvg=True,
     neighbors=True,
     use_rep="X_pca",
-    umap=True,
+    umap=False,
 ):
     """Apply feature selection and dimensionality reduction steps.
 
@@ -696,7 +702,15 @@ def save_seurat(adata, path, batch, hvgs=None):
     :param batch: key in ``adata.obs`` that holds batch assigments
     :param hvgs: list of highly variable genes
     """
-    import re
+    try:
+        import anndata2ri
+        import rpy2.rinterface_lib.callbacks
+        import rpy2.rinterface_lib.embedded
+        import rpy2.robjects as ro
+
+        rpy2.rinterface_lib.callbacks.logger.setLevel(logging.ERROR)
+    except ModuleNotFoundError as e:
+        raise OptionalDependencyNotInstalled(e)
 
     try:
         ro.r("library(Seurat)")
@@ -740,6 +754,15 @@ def read_seurat(path):
 
     :param path: file path to saved file
     """
+    try:
+        import anndata2ri
+        import rpy2.rinterface_lib.callbacks
+        import rpy2.rinterface_lib.embedded
+        import rpy2.robjects as ro
+
+        rpy2.rinterface_lib.callbacks.logger.setLevel(logging.ERROR)
+    except ModuleNotFoundError as e:
+        raise OptionalDependencyNotInstalled(e)
 
     try:
         ro.r("library(Seurat)")
@@ -772,9 +795,17 @@ def read_conos(inPath, dir_path=None):
     :param inPath:
     :param dir_path:
     """
+    try:
+        import rpy2.rinterface_lib.callbacks
+        import rpy2.rinterface_lib.embedded
+        import rpy2.robjects as ro
+
+        rpy2.rinterface_lib.callbacks.logger.setLevel(logging.ERROR)
+    except ModuleNotFoundError as e:
+        raise OptionalDependencyNotInstalled(e)
+
     from shutil import rmtree
 
-    import pandas as pd
     from scipy.io import mmread
 
     if dir_path is None:
